package net.knarcraft.blacksmith.command;

import net.knarcraft.blacksmith.BlacksmithPlugin;
import net.knarcraft.blacksmith.container.ActionCost;
import net.knarcraft.blacksmith.formatting.BlacksmithTranslatableMessage;
import org.bukkit.command.Command;
import org.bukkit.command.CommandSender;
import org.bukkit.command.TabExecutor;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.List;

public class CostCommand implements TabExecutor {

    @Override
    public boolean onCommand(@NotNull CommandSender commandSender, @NotNull Command command, @NotNull String s, @NotNull String[] arguments) {
        //TODO: Whenever a cost is specified (not for the per-material and per-enchantment costs), allow either a simple
        // cost or an ActionCost. When loading costs, first try and parse a double. If not, parse an ActionCost object.
        // TODO: The command should look like "blacksmithEdit <option> <simple|advanced> <double|economy|item|permission|exp>
        //  <double|blank/null|comma-separated-string|integer>"

        //TODO: Check arguments size
        if (arguments.length < 2) {
            return false;
        }

        ActionCost actionCost;

        switch (arguments[0]) {
            case "simple":
                // TODO: Do something with the cost
                double cost = parseSimpleCost(commandSender, arguments[1]);
                break;
            case "advanced":
                switch (arguments[1]) {
                    case "economy":
                        // TODO: Expect the next argument to be the cost
                        break;
                    case "item":
                        // TODO: The next argument would either be "null" to clear the value, or "mainHand" to use the item in the player's main hand
                        break;
                    case "permission":
                        // TODO: The next argument will be a comma-separated list of permissions
                        break;
                    case "exp":
                        // TODO: Expect the next argument to be an integer
                        break;
                }
                break;
            default:
                return false;
        }
        return false;
    }

    @Override
    public @Nullable List<String> onTabComplete(@NotNull CommandSender commandSender, @NotNull Command command,
                                                @NotNull String s, @NotNull String[] strings) {
        return List.of();
    }

    /**
     * Parses a simple double cost
     *
     * @param commandSender <p>The command sender to notify of any problems</p>
     * @param costString    <p>The string to parse into a cost</p>
     * @return <p>The parsed cost</p>
     * @throws IllegalArgumentException <p>If the specified cost is invalid</p>
     */
    private double parseSimpleCost(@NotNull CommandSender commandSender,
                                   @NotNull String costString) throws IllegalArgumentException {
        try {
            double cost = Double.parseDouble(costString);
            if (cost < 0) {
                throw new NumberFormatException();
            }
            return cost;
        } catch (NumberFormatException exception) {
            BlacksmithPlugin.getStringFormatter().displayErrorMessage(commandSender,
                    BlacksmithTranslatableMessage.DOUBLE_COST_REQUIRED);
            throw new IllegalArgumentException("Invalid cost given");
        }
    }

}
